==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/bestand/v20130701/Attachment.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.bestand.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for Attachment complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="Attachment"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="base64Attachment" type="{http://www.w3.org/2001/XMLSchema}base64Binary"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Attachment", propOrder = {
    "base64Attachment"
})
public class Attachment {

    @XmlElement(required = true)
    protected byte[] base64Attachment;

    /**
     * Gets the value of the base64Attachment property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getBase64Attachment() {
        return base64Attachment;
    }

    /**
     * Sets the value of the base64Attachment property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setBase64Attachment(byte[] value) {
        this.base64Attachment = value;
    }

}

==> kadaster-gds2-2.7-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/bestand/v20130701/Attachment.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.bestand.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for Attachment complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Attachment"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="base64Attachment" type="{http://www.w3.org/2001/XMLSchema}base64Binary"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Attachment", propOrder = {
    "base64Attachment"
})
public class Attachment {

    @XmlElement(required = true)
    protected byte[] base64Attachment;

    /**
     * Gets the value of the base64Attachment property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getBase64Attachment() {
        return base64Attachment;
    }

    /**
     * Sets the value of the base64Attachment property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setBase64Attachment(byte[] value) {
        this.base64Attachment = value;
    }

}
